@@ -1,9 +1,10 @@
+"""Contains functions for data readers."""
 import json
 import re
 import urllib
 from builtins import next
 from collections import OrderedDict
-from io import BytesIO, StringIO, TextIOWrapper, open
+from io import BytesIO, TextIOWrapper
 
 import dateutil
 import pandas as pd
@@ -12,15 +13,15 @@ import requests
 from chardet.universaldetector import UniversalDetector
 
 from .. import dp_logging
-from .filepath_or_buffer import FileOrBufferHandler, is_stream_buffer
+from .filepath_or_buffer import FileOrBufferHandler, is_stream_buffer  # NOQA
 
 logger = dp_logging.get_child_logger(__name__)
 
 
 def data_generator(data_list):
     """
-    Takes a list and returns a generator on the list.
-    
+    Take a list and return a generator on the list.
+
     :param data_list: list of strings
     :type data_list: list
     :return: item from the list
@@ -32,8 +33,8 @@ def data_generator(data_list):
 
 def generator_on_file(file_object):
     """
-    Takes a file and returns a generator that returns lines
-    
+    Take a file and return a generator that returns lines.
+
     :param file_path: path to the file
     :type file_path: path
     :return: Line from file
@@ -50,8 +51,9 @@ def generator_on_file(file_object):
 
 def convert_int_to_string(x):
     """
-    Converts the given input to string. In particular, it is int,
-    it converts it ensuring there is no . or 00 in the converted string.
+    Convert the given input to string.
+
+    In particular, it is int, it converts it ensuring there is no . or 00.
     In addition, if the input is np.nan, the output will be 'nan' which is
     what we need to handle data properly.
 
@@ -63,14 +65,14 @@ def convert_int_to_string(x):
     try:
         # TODO: Check if float is necessary
         return str(int(float(x)))
-    except:
+    except Exception:
         return str(x)
 
 
 def unicode_to_str(data, ignore_dicts=False):
     """
     Convert data to string representation if it is a unicode string.
-    
+
     :param data: input data
     :type data: str
     :param ignore_dicts: if set, ignore the dictionary type processing
@@ -79,7 +81,7 @@ def unicode_to_str(data, ignore_dicts=False):
     :rtype: str
     """
     if isinstance(data, str):
-        return data.encode('utf-8').decode()
+        return data.encode("utf-8").decode()
 
     # if data is a list of values
     if isinstance(data, list):
@@ -87,24 +89,25 @@ def unicode_to_str(data, ignore_dicts=False):
 
     # if data is a dictionary
     if isinstance(data, dict) and not ignore_dicts:
-        return {unicode_to_str(key, ignore_dicts=True):
-                    unicode_to_str(value, ignore_dicts=True)
-                for key, value in data.items()
-                }
+        return {
+            unicode_to_str(key, ignore_dicts=True): unicode_to_str(
+                value, ignore_dicts=True
+            )
+            for key, value in data.items()
+        }
 
     return data
 
 
 def json_to_dataframe(json_lines, selected_columns=None, read_in_string=False):
     """
-    This function takes a list of json objects and returns the dataframe
-    representing the json list.
-    
+    Take list of json objects and return dataframe representing json list.
+
     :param json_lines: list of json objects
     :type json_lines: list(dict)
     :param selected_columns: a list of keys to be processed
     :type selected_columns: list(str)
-    :param read_in_string: if True, all the values in dataframe will be 
+    :param read_in_string: if True, all the values in dataframe will be
         converted to string
     :type read_in_string: bool
     :return: dataframe converted from json list and list of dtypes for each
@@ -117,8 +120,8 @@ def json_to_dataframe(json_lines, selected_columns=None, read_in_string=False):
     first_item_type = type(json_lines[0])
     if not all(map(lambda x: isinstance(x, first_item_type), json_lines)):
         raise ValueError(
-            'Only JSON which represents structured data is supported for this '
-            'data type (i.e. list-dicts).'
+            "Only JSON which represents structured data is supported for this "
+            "data type (i.e. list-dicts)."
         )
     elif first_item_type == dict:
         df = pd.json_normalize(json_lines)
@@ -136,8 +139,9 @@ def json_to_dataframe(json_lines, selected_columns=None, read_in_string=False):
 
 def read_json_df(data_generator, selected_columns=None, read_in_string=False):
     """
-    This function returns an iterator that returns a chunk of data
-    as dataframe in each call. The source of input to this function is either a
+    Return an iterator that returns a chunk of data as dataframe in each call.
+
+    The source of input to this function is either a
     file or a list of JSON structured strings. If the file path is given as
     input, the file is expected to have one JSON structures in each line. The
     lines that are not valid json will be ignored. Therefore, a file with
@@ -145,9 +149,9 @@ def read_json_df(data_generator, selected_columns=None, read_in_string=False):
     input is a data list, it is expected to be a list of strings where each
     string is a valid JSON object. if the individual object is not valid
     JSON, it will be ignored.
-    
+
     NOTE: both data_list and file_path cannot be passed at the same time.
-    
+
     :param data_generator: The generator you want to read.
     :type data_generator: generator
     :param selected_columns: a list of keys to be processed
@@ -159,7 +163,6 @@ def read_json_df(data_generator, selected_columns=None, read_in_string=False):
         each call as well as original dtypes of the dataframe columns.
     :rtype: typle(Iterator(pd.DataFrame), pd.Series(dtypes)
     """
-
     lines = list()
     k = 0
     while True:
@@ -172,10 +175,10 @@ def read_json_df(data_generator, selected_columns=None, read_in_string=False):
             break
         try:
             obj = unicode_to_str(
-                json.loads(raw_line,
-                           object_hook=unicode_to_str,
-                           object_pairs_hook=OrderedDict),
-                ignore_dicts=True
+                json.loads(
+                    raw_line, object_hook=unicode_to_str, object_pairs_hook=OrderedDict
+                ),
+                ignore_dicts=True,
             )
             lines.append(obj)
         except ValueError:
@@ -183,19 +186,21 @@ def read_json_df(data_generator, selected_columns=None, read_in_string=False):
             # To ignore malformatted lines.
         k += 1
     if not lines and k:
-        raise ValueError('No JSON data could be read from these data.')
+        raise ValueError("No JSON data could be read from these data.")
     return json_to_dataframe(lines, selected_columns, read_in_string)
 
 
 def read_json(data_generator, selected_columns=None, read_in_string=False):
     """
-    This function returns the lines of a json. The source of input to this 
-    function is either a file or a list of JSON structured strings. If the 
-    file path is given as input, the file is expected to have one JSON 
-    structures in each line. The lines that are not valid json will be ignored. 
-    Therefore, a file with pretty printed JSON objects will not be considered 
-    valid JSON. If the input is a data list, it is expected to be a list of 
-    strings where each string is a valid JSON object. if the individual object 
+    Return the lines of a json.
+
+    The source of input to this function is either a file or
+    a list of JSON structured strings.
+    If the file path is given as input, the file is expected to have one JSON
+    structures in each line. The lines that are not valid json will be ignored.
+    Therefore, a file with pretty printed JSON objects will not be considered
+    valid JSON. If the input is a data list, it is expected to be a list of
+    strings where each string is a valid JSON object. if the individual object
     is not valid JSON, it will be ignored.
 
     NOTE: both data_list and file_path cannot be passed at the same time.
@@ -210,7 +215,6 @@ def read_json(data_generator, selected_columns=None, read_in_string=False):
     :return: returns the lines of a json file
     :rtype: list(dict)
     """
-
     lines = list()
     k = 0
     while True:
@@ -223,10 +227,10 @@ def read_json(data_generator, selected_columns=None, read_in_string=False):
             break
         try:
             obj = unicode_to_str(
-                json.loads(raw_line,
-                           object_hook=unicode_to_str,
-                           object_pairs_hook=OrderedDict),
-                ignore_dicts=True
+                json.loads(
+                    raw_line, object_hook=unicode_to_str, object_pairs_hook=OrderedDict
+                ),
+                ignore_dicts=True,
             )
             lines.append(obj)
         except ValueError:
@@ -234,15 +238,21 @@ def read_json(data_generator, selected_columns=None, read_in_string=False):
             # To ignore malformatted lines.
         k += 1
     if not lines and k:
-        raise ValueError('No JSON data could be read from these data.')
+        raise ValueError("No JSON data could be read from these data.")
     return lines
 
 
-def read_csv_df(file_path, delimiter, header, selected_columns=[],
-                read_in_string=False, encoding='utf-8'):
+def read_csv_df(
+    file_path,
+    delimiter,
+    header,
+    selected_columns=[],
+    read_in_string=False,
+    encoding="utf-8",
+):
     """
-    Reads a CSV file in chunks and returns a dataframe in the form of iterator.
-    
+    Read a CSV file in chunks and return dataframe in form of iterator.
+
     :param file_path: path to the CSV file.
     :type file_path: str
     :param delimiter: character used to separate csv values.
@@ -258,25 +268,23 @@ def read_csv_df(file_path, delimiter, header, selected_columns=[],
     :rtype: pd.DataFrame
     """
     args = {
-        'delimiter': delimiter,
-        'header': header,
-        'iterator': True,
-        'dtype': 'object',
-        'keep_default_na': False,
-        'encoding': encoding
+        "delimiter": delimiter,
+        "header": header,
+        "iterator": True,
+        "dtype": "object",
+        "keep_default_na": False,
+        "encoding": encoding,
     }
 
     # If a header can be identified, don't skip blanks
     if header is not None:
-        args.update({
-            'skip_blank_lines': False
-        })
+        args.update({"skip_blank_lines": False})
 
     if read_in_string:
-        args['dtype'] = str
+        args["dtype"] = str
 
     if len(selected_columns) > 0:
-        args['usecols'] = selected_columns
+        args["usecols"] = selected_columns
 
     # account for py3.6 requirement for pandas, can remove if >= py3.7
     is_buf_wrapped = False
@@ -285,10 +293,10 @@ def read_csv_df(file_path, delimiter, header, selected_columns=[],
         # in 3.6 this avoids read_csv wrapping the stream and closing too early
         file_path = TextIOWrapper(file_path, encoding=encoding)
         is_buf_wrapped = True
-        
+
     fo = pd.read_csv(file_path, **args)
     data = fo.read()
-    
+
     # if the buffer was wrapped, detach it before returning
     if is_buf_wrapped:
         file_path.detach()
@@ -299,14 +307,13 @@ def read_csv_df(file_path, delimiter, header, selected_columns=[],
 
 def read_parquet_df(file_path, selected_columns=None, read_in_string=False):
     """
-    Returns an iterator that returns one row group each time.
-    
+    Return an iterator that returns one row group each time.
+
     :param file_path: path to the Parquet file.
     :type file_path: str
     :return:
     :rtype: Iterator(pd.DataFrame)
     """
-
     parquet_file = pq.ParquetFile(file_path)
     data = pd.DataFrame()
     for i in range(parquet_file.num_row_groups):
@@ -314,17 +321,21 @@ def read_parquet_df(file_path, selected_columns=None, read_in_string=False):
         data_row_df = parquet_file.read_row_group(i).to_pandas()
 
         # Convert all the unicode columns to utf-8
-        types = data_row_df.apply(lambda x: pd.api.types.infer_dtype(
-                                                x.values, skipna=True))
+        types = data_row_df.apply(
+            lambda x: pd.api.types.infer_dtype(x.values, skipna=True)
+        )
 
-        mixed_and_unicode_cols = types[types == 'unicode'] \
-            .index.union(types[types == 'mixed'].index)
+        mixed_and_unicode_cols = types[types == "unicode"].index.union(
+            types[types == "mixed"].index
+        )
 
         for col in mixed_and_unicode_cols:
             data_row_df[col] = data_row_df[col].apply(
-                lambda x: x.encode('utf-8').strip() if isinstance(x, str) else x)
+                lambda x: x.encode("utf-8").strip() if isinstance(x, str) else x
+            )
             data_row_df[col] = data_row_df[col].apply(
-                lambda x: x.decode('utf-8').strip() if isinstance(x, bytes) else x)
+                lambda x: x.decode("utf-8").strip() if isinstance(x, bytes) else x
+            )
 
         if selected_columns:
             data_row_df = data_row_df[selected_columns]
@@ -340,8 +351,10 @@ def read_parquet_df(file_path, selected_columns=None, read_in_string=False):
 
 def read_text_as_list_of_strs(file_path, encoding=None):
     """
-    Returns a list of strings relative to the chunk size. Each line is 1 chunk.
-    
+    Return list of strings relative to the chunk size.
+
+    Each line is 1 chunk.
+
     :param file_path: path to the file
     :type file_path: str
     :return:
@@ -356,9 +369,8 @@ def read_text_as_list_of_strs(file_path, encoding=None):
 
 def detect_file_encoding(file_path, buffer_size=1024, max_lines=20):
     """
-    Determines the encoding of files within the initial `max_lines` of length
-    `buffer_size`.
-    
+    Determine encoding of files within initial `max_lines` of length `buffer_size`.
+
     :param file_path: path to the file
     :type file_path: str
     :param buffer_size: buffer length for each line being read
@@ -370,7 +382,7 @@ def detect_file_encoding(file_path, buffer_size=1024, max_lines=20):
     """
     detector = UniversalDetector()
     line_count = 0
-    with FileOrBufferHandler(file_path, 'rb') as input_file:
+    with FileOrBufferHandler(file_path, "rb") as input_file:
         chunk = input_file.read(buffer_size)
         while chunk and line_count < max_lines:
             detector.feed(chunk)
@@ -380,100 +392,111 @@ def detect_file_encoding(file_path, buffer_size=1024, max_lines=20):
     encoding = detector.result["encoding"]
 
     # Typical file representation is utf-8 instead of ascii, treat as such.
-    if not encoding or encoding.lower() in ['ascii', 'windows-1254']:
-        encoding = 'utf-8'
+    if not encoding or encoding.lower() in ["ascii", "windows-1254"]:
+        encoding = "utf-8"
 
     # Check if encoding can be used to decode without throwing an error
     def _decode_is_valid(encoding):
-        try: 
+        try:
             with FileOrBufferHandler(file_path, encoding=encoding) as input_file:
-                input_file.read(1024*1024)
+                input_file.read(1024 * 1024)
                 return True
-        except:
+        except Exception:
             return False
 
     if not _decode_is_valid(encoding):
         try:
             from charset_normalizer import CharsetNormalizerMatches as CnM
 
-            # Try with small sample 
-            with FileOrBufferHandler(file_path, 'rb') as input_file:
+            # Try with small sample
+            with FileOrBufferHandler(file_path, "rb") as input_file:
                 raw_data = input_file.read(10000)
-                result = CnM.from_bytes(raw_data, steps=5, 
-                                        chunk_size=512, threshold=0.2,
-                                        cp_isolation=None, cp_exclusion=None,
-                                        preemptive_behaviour=True, explain=False)
+                result = CnM.from_bytes(
+                    raw_data,
+                    steps=5,
+                    chunk_size=512,
+                    threshold=0.2,
+                    cp_isolation=None,
+                    cp_exclusion=None,
+                    preemptive_behaviour=True,
+                    explain=False,
+                )
                 result = result.best()
             if result:
                 if result.first():
                     encoding = result.first().encoding
 
             # Try again with full sample
-            if not _decode_is_valid(encoding): 
-                with FileOrBufferHandler(file_path, 'rb') as input_file:
-                    raw_data = input_file.read(max_lines*buffer_size)
-                    result = CnM.from_bytes(raw_data, steps=max_lines, 
-                                            chunk_size=buffer_size, threshold=0.2,
-                                            cp_isolation=None, cp_exclusion=None,
-                                            preemptive_behaviour=True, explain=False)
+            if not _decode_is_valid(encoding):
+                with FileOrBufferHandler(file_path, "rb") as input_file:
+                    raw_data = input_file.read(max_lines * buffer_size)
+                    result = CnM.from_bytes(
+                        raw_data,
+                        steps=max_lines,
+                        chunk_size=buffer_size,
+                        threshold=0.2,
+                        cp_isolation=None,
+                        cp_exclusion=None,
+                        preemptive_behaviour=True,
+                        explain=False,
+                    )
                     result = result.best()
                 if result:
                     if result.first():
                         encoding = result.first().encoding
 
-        except:
-            logger.info("Install charset_normalizer for improved file "
-                        "encoding detection")
+        except Exception:
+            logger.info(
+                "Install charset_normalizer for improved file " "encoding detection"
+            )
 
     # If no encoding is still found, default to utf-8
     if not encoding:
-        encoding = 'utf-8'
+        encoding = "utf-8"
     return encoding.lower()
 
 
 def detect_cell_type(cell):
     """
-    Detects the cell type (int, float, etc)
+    Detect the cell type (int, float, etc).
 
     :param cell: String designated for data type detection
     :type cell: str
     """
-    
-    cell_type = 'str'
+    cell_type = "str"
     if len(cell) == 0:
-        cell_type = 'none'
+        cell_type = "none"
     else:
 
         try:
             if dateutil.parser.parse(cell, fuzzy=False):
-                cell_type = 'date'
+                cell_type = "date"
         except (ValueError, OverflowError, TypeError):
             pass
 
         try:
             f_cell = float(cell)
-            cell_type = 'float'
+            cell_type = "float"
             if f_cell.is_integer():
-                cell_type = 'int'
+                cell_type = "int"
         except ValueError:
             pass
 
         if cell.isupper():
-            cell_type = 'upstr'
-            
+            cell_type = "upstr"
+
     return cell_type
 
 
 def get_delimiter_regex(delimiter=",", quotechar=","):
     """
-    Builds regex for delimiter checks
-    
+    Build regex for delimiter checks.
+
     :param delimiter: Delimiter to be added to regex
     :type delimiter: str
     :param quotechar: Quotechar to be added to regex
     :type delimiter: str
     """
-    
     if delimiter is None:
         return ""
 
@@ -481,15 +504,15 @@ def get_delimiter_regex(delimiter=",", quotechar=","):
         quotechar = '"'
 
     delimiter_regex = re.escape(str(delimiter))
-    quotechar_escape= re.escape(quotechar)
-    quotechar_regex = "(?=" 
-    quotechar_regex +=  "(?:"
-    quotechar_regex +=    "[^"+quotechar_escape+"]*"
-    quotechar_regex +=    quotechar_escape
-    quotechar_regex +=    "[^"+quotechar_escape+"]*"
-    quotechar_regex +=    quotechar_escape
-    quotechar_regex +=   ")*"
-    quotechar_regex +=   "[^"+quotechar_escape+"]*"
+    quotechar_escape = re.escape(quotechar)
+    quotechar_regex = "(?="
+    quotechar_regex += "(?:"
+    quotechar_regex += "[^" + quotechar_escape + "]*"
+    quotechar_regex += quotechar_escape
+    quotechar_regex += "[^" + quotechar_escape + "]*"
+    quotechar_regex += quotechar_escape
+    quotechar_regex += ")*"
+    quotechar_regex += "[^" + quotechar_escape + "]*"
     quotechar_regex += "$)"
 
     return re.compile(delimiter_regex + quotechar_regex)
@@ -497,10 +520,10 @@ def get_delimiter_regex(delimiter=",", quotechar=","):
 
 def find_nth_loc(string=None, search_query=None, n=0, ignore_consecutive=True):
     """
-    Searches the string via the search_query and
-    returns the nth index in which the query occurs.
+    Search string via search_query and return nth index in which query occurs.
+
     If there are less than 'n' the last loc is returned
-    
+
     :param string: Input string, to be searched
     :type string: str
     :param search_query: char(s) to find nth occurrence of
@@ -509,13 +532,12 @@ def find_nth_loc(string=None, search_query=None, n=0, ignore_consecutive=True):
     :type n: int
     :param ignore_consecutive: Ignore consecutive matches in the search query.
     :type ignore_consecutive: bool
-    
+
     :return idx: Index of the nth or last occurrence of the search_query
     :rtype idx: int
     :return id_count: Number of identifications prior to idx
     :rtype id_count: int
     """
-
     # Return base case, if there's no string, query or n
     if not string or not search_query or 0 >= n:
         return -1, 0
@@ -523,7 +545,7 @@ def find_nth_loc(string=None, search_query=None, n=0, ignore_consecutive=True):
     # create the search pattern
     pattern = re.escape(search_query)
     if ignore_consecutive:
-        pattern += '+'
+        pattern += "+"
     r_iter = re.finditer(pattern, string)
 
     # Find index of nth occurrence of search_query
@@ -542,10 +564,11 @@ def find_nth_loc(string=None, search_query=None, n=0, ignore_consecutive=True):
     return idx, id_count
 
 
-def load_as_str_from_file(file_path, file_encoding=None, max_lines=10,
-                          max_bytes=65536, chunk_size_bytes=1024):
+def load_as_str_from_file(
+    file_path, file_encoding=None, max_lines=10, max_bytes=65536, chunk_size_bytes=1024
+):
     """
-    Loads data from a csv file up to a specific line OR byte_size.
+    Load data from a csv file up to a specific line OR byte_size.
 
     :param file_path: Path to file to load data from
     :type file_path: str
@@ -557,39 +580,40 @@ def load_as_str_from_file(file_path, file_encoding=None, max_lines=10,
     :type max_bytes: int
     :param chunk_size_bytes: Chunk size to load every data load
     :type chunk_size_bytes: int
-    
+
     :return: Data as string
     :rtype: str
     """
-
     data_as_str = ""
     total_occurrences = 0
     with FileOrBufferHandler(file_path, encoding=file_encoding) as csvfile:
 
         sample_size_bytes = min(max_bytes, chunk_size_bytes)
-        
+
         # Read the file until the appropriate number of occurrences
         for byte_count in range(0, max_bytes, sample_size_bytes):
-            
+
             sample_lines = csvfile.read(sample_size_bytes)
             if len(sample_lines) == 0:
                 break  # No more bytes in file
 
             # Number of lines remaining to be added to data_as_str
             remaining_lines = max_lines - total_occurrences
-            
+
             # Return either the last index of sample_lines OR
             # the index of the newline char that matches remaining_lines
-            search_query_value = '\n'
-            if (isinstance(sample_lines, bytes)):
-                search_query_value = b'\n'
+            search_query_value = "\n"
+            if isinstance(sample_lines, bytes):
+                search_query_value = b"\n"
 
             start_loc = 0
             len_sample_lines = len(sample_lines)
             while start_loc < len_sample_lines - 1 and total_occurrences < max_lines:
-                loc, occurrence = find_nth_loc(sample_lines[start_loc:],
-                                               search_query=search_query_value,
-                                               n=remaining_lines)
+                loc, occurrence = find_nth_loc(
+                    sample_lines[start_loc:],
+                    search_query=search_query_value,
+                    n=remaining_lines,
+                )
 
                 # Add sample_lines to data_as_str no more than max_lines
                 if isinstance(sample_lines[start_loc:loc], bytes):
@@ -607,9 +631,9 @@ def load_as_str_from_file(file_path, file_encoding=None, max_lines=10,
 
 def is_valid_url(url_as_string):
     """
-    Determines whether a given string is a valid URL
+    Determine whether a given string is a valid URL.
 
-    :param url_as_string: string to be tested if URL 
+    :param url_as_string: string to be tested if URL
     :type url_as_string: str
     :return: true if string is a valid URL
     :rtype: boolean
@@ -624,11 +648,11 @@ def is_valid_url(url_as_string):
 
 def url_to_bytes(url_as_string, options):
     """
-    Reads in URL and converts it to a byte stream
+    Read in URL and converts it to a byte stream.
 
-    :param url_as_string: string to read as URL 
+    :param url_as_string: string to read as URL
     :type url_as_string: str
-    :param options: options for the url 
+    :param options: options for the url
     :type options: dict
     :return: BytesIO stream of data downloaded from URL
     :rtype: BytesIO stream
@@ -636,17 +660,20 @@ def url_to_bytes(url_as_string, options):
     stream = BytesIO()
 
     verify_ssl = True
-    if 'verify_ssl' in options:
-        verify_ssl = options['verify_ssl']
+    if "verify_ssl" in options:
+        verify_ssl = options["verify_ssl"]
 
     try:
         with requests.get(url_as_string, stream=True, verify=verify_ssl) as url:
             url.raise_for_status()
-            if 'Content-length' in url.headers \
-                    and int(url.headers['Content-length']) >= 1024 ** 3:
+            if (
+                "Content-length" in url.headers
+                and int(url.headers["Content-length"]) >= 1024**3
+            ):
 
-                raise ValueError('The downloaded file from the url may not be '
-                                 'larger than 1GB')
+                raise ValueError(
+                    "The downloaded file from the url may not be " "larger than 1GB"
+                )
 
             total_bytes = 0
             c_size = 8192
@@ -655,15 +682,17 @@ def url_to_bytes(url_as_string, options):
                 stream.write(chunk)
                 total_bytes += c_size
 
-                if total_bytes > 1024 ** 3:
-                    raise ValueError('The downloaded file from the url may not '
-                                     'be larger than 1GB')
+                if total_bytes > 1024**3:
+                    raise ValueError(
+                        "The downloaded file from the url may not " "be larger than 1GB"
+                    )
     except requests.exceptions.SSLError as e:
         raise RuntimeError(
             "The URL given has an untrusted SSL certificate. Although highly "
             "discouraged, you can proceed with reading the data by setting "
             "'verify_ssl' to False in options "
-            "(i.e. options=dict(verify_ssl=False)).") from e
+            "(i.e. options=dict(verify_ssl=False))."
+        ) from e
 
     stream.seek(0)
     return stream
