@@ -1,16 +1,16 @@
+"""Contains functions and classes for handling filepaths and buffers."""
 from io import BytesIO, StringIO, TextIOWrapper, open
 
 
 def is_stream_buffer(filepath_or_buffer):
     """
-    Determines whether a given argument is a filepath or buffer.
+    Determine whether a given argument is a filepath or buffer.
 
     :param filepath_or_buffer: path to the file or buffer
     :type filepath_or_buffer: str
     :return: true if string is a buffer or false if string is a filepath
     :rtype: boolean
     """
-
     if isinstance(filepath_or_buffer, (StringIO, BytesIO)):
         return True
     return False
@@ -18,14 +18,23 @@ def is_stream_buffer(filepath_or_buffer):
 
 class FileOrBufferHandler:
     """
-    FileOrBufferHandler class to read a filepath or buffer in and always
-    return a readable buffer.
+    FileOrBufferHandler class to read a filepath or buffer in.
+
+    Always returns a readable buffer.
     """
 
-    def __init__(self, filepath_or_buffer, open_method='r', encoding=None,
-                 seek_offset=None, seek_whence=0):
+    def __init__(
+        self,
+        filepath_or_buffer,
+        open_method="r",
+        encoding=None,
+        seek_offset=None,
+        seek_whence=0,
+    ):
         """
-        Context manager class used for inputting a file or buffer and returning
+        Initialize Context manager class.
+
+        Used for inputting a file or buffer and returning
         a structure that is always a buffer.
 
         :param filepath_or_buffer: path to the file being loaded or buffer
@@ -45,22 +54,25 @@ class FileOrBufferHandler:
         self._is_wrapped = False
 
     def __enter__(self):
+        """Open resources."""
         if isinstance(self._filepath_or_buffer, str):
             self._filepath_or_buffer = open(
-                self._filepath_or_buffer, self.open_method,
-                encoding=self._encoding)
+                self._filepath_or_buffer, self.open_method, encoding=self._encoding
+            )
 
-        elif isinstance(self._filepath_or_buffer, BytesIO) \
-                and self.open_method == 'r':
-            self._filepath_or_buffer = \
-                TextIOWrapper(self._filepath_or_buffer, encoding=self._encoding)
+        elif isinstance(self._filepath_or_buffer, BytesIO) and self.open_method == "r":
+            self._filepath_or_buffer = TextIOWrapper(
+                self._filepath_or_buffer, encoding=self._encoding
+            )
             self._is_wrapped = True
 
         elif not is_stream_buffer(self._filepath_or_buffer):
             # Raise AttributeError if attribute value not found.
-            raise AttributeError(f'Type {type(self._filepath_or_buffer)} is '
-                                 f'invalid. filepath_or_buffer must be a '
-                                 f'string or StringIO/BytesIO object')
+            raise AttributeError(
+                f"Type {type(self._filepath_or_buffer)} is "
+                f"invalid. filepath_or_buffer must be a "
+                f"string or StringIO/BytesIO object"
+            )
 
         if self.seek_offset is not None:
             self._filepath_or_buffer.seek(self.seek_offset, self.seek_whence)
@@ -68,6 +80,7 @@ class FileOrBufferHandler:
         return self._filepath_or_buffer
 
     def __exit__(self, exc_type, exc_value, exc_traceback):
+        """Release resources."""
         # Need to detach buffer if wrapped (i.e. BytesIO opened with 'r')
         if self._is_wrapped:
             wrapper = self._filepath_or_buffer
