@@ -1,15 +1,9 @@
 #!/usr/bin/env python
-"""
-coding=utf-8
-
-Profiles the data.
-"""
+"""Contains parent column profiler class."""
 
 from __future__ import division, print_function
 
 import abc
-import functools
-import time
 import warnings
 from collections import defaultdict
 
@@ -20,9 +14,8 @@ from . import utils
 
 
 class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
-    """
-    Abstract class for profiling a column of data.
-    """
+    """Abstract class for profiling a column of data."""
+
     col_type = None
 
     # This specifies the minimum percent of elements in a column to meet the
@@ -34,7 +27,7 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
 
     def __init__(self, name):
         """
-        Initialization of base class properties for the subclass.
+        Initialize base class properties for the subclass.
 
         :param name: Name of the dataset
         :type name: String
@@ -46,11 +39,11 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
         self.times = defaultdict(float)
         self.thread_safe = True
 
-
     @staticmethod
     def _combine_unique_sets(a, b):  # TODO: Not needed for data labeling
         """
-        Method to union two lists.
+        Unify two lists.
+
         :type a: list
         :type b: list
         :rtype: list
@@ -63,16 +56,16 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
         elif not b:
             combined_list = set(a)
         else:
-            combined_list = set().union(a,b)
-        combined_list = list(combined_list)        
+            combined_list = set().union(a, b)
+        combined_list = list(combined_list)
         return combined_list
 
-        
     @staticmethod
     def _timeit(method=None, name=None):
         """
-        Measure execution time of provided method
-        Records time into times dictionary
+        Measure execution time of provided method.
+
+        Records time into times dictionary.
 
         :param method: method to time
         :type method: Callable
@@ -84,8 +77,7 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
     @staticmethod
     def _filter_properties_w_options(calculations, options):
         """
-        Cycles through the calculations and turns off the ones that are
-        disabled.
+        Cycle through the calculations and turns off the ones that are disabled.
 
         :param calculations: Contains all the column calculations.
         :type calculations: Dict
@@ -96,16 +88,17 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
             if options and not options.is_prop_enabled(prop):
                 del calculations[prop]
 
-    def _perform_property_calcs(self, calculations, df_series,
-                                prev_dependent_properties, subset_properties):
+    def _perform_property_calcs(
+        self, calculations, df_series, prev_dependent_properties, subset_properties
+    ):
         """
-        Cycles through the properties of the columns and calculate them.
+        Cycle through the properties of the columns and calculate them.
 
         :param calculations: Contains all the column calculations.
         :type calculations: dict
         :param df_series: Data to be profiled
         :type df_series: pandas.Dataframe
-        :param prev_dependent_properties: Contains all the previous properties 
+        :param prev_dependent_properties: Contains all the previous properties
         that the calculations depend on.
         :type prev_dependent_properties: dict
         :param subset_properties: Contains the results of the properties of the
@@ -114,16 +107,14 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
         :return: None
         """
         for prop in calculations:
-            calculations[prop](self,
-                               df_series,
-                               prev_dependent_properties,
-                               subset_properties)
+            calculations[prop](
+                self, df_series, prev_dependent_properties, subset_properties
+            )
 
     @staticmethod
     def _merge_calculations(merged_profile_calcs, profile1_calcs, profile2_calcs):
         """
-        Merges the calculations of two profiles to the lowest common
-        denominator.
+        Merge the calculations of two profiles to the lowest common denominator.
 
         :param merged_profile_calcs: default calculations of the merged profile
         :type merged_profile_calcs: dict
@@ -138,12 +129,15 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
             if calc not in profile1_calcs or calc not in profile2_calcs:
                 del merged_profile_calcs[calc]
                 if calc in profile1_calcs or calc in profile2_calcs:
-                    warnings.warn("{} is disabled because it is not enabled in "
-                                  "both profiles.".format(calc), RuntimeWarning)
+                    warnings.warn(
+                        "{} is disabled because it is not enabled in "
+                        "both profiles.".format(calc),
+                        RuntimeWarning,
+                    )
 
     def _add_helper(self, other1, other2):
         """
-        Merges the properties of two BaseColumnProfile objects
+        Merge the properties of two BaseColumnProfile objects.
 
         :param other1: first BaseColumn profile
         :param other2: second BaseColumn profile
@@ -155,22 +149,25 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
         elif other1.col_index == other2.col_index:
             self.col_index = other1.col_index
         else:
-            raise ValueError("Column indexes unmatched: {} != {}"
-                             .format(other1.col_index, other2.col_index))
+            raise ValueError(
+                "Column indexes unmatched: {} != {}".format(
+                    other1.col_index, other2.col_index
+                )
+            )
         if other1.name == other2.name:
             self.name = other1.name
         else:
-            raise ValueError("Column names unmatched: {} != {}"
-                             .format(other1.name, other2.name))
+            raise ValueError(
+                "Column names unmatched: {} != {}".format(other1.name, other2.name)
+            )
 
-        self.times = utils.add_nested_dictionaries(other1.times,
-                                                   other2.times)
+        self.times = utils.add_nested_dictionaries(other1.times, other2.times)
 
         self.sample_size = other1.sample_size + other2.sample_size
-        
+
     def diff(self, other_profile, options=None):
         """
-        Finds the differences for columns.
+        Find the differences for columns.
 
         :param other_profile: profile to find the difference with
         :type other_profile: BaseColumnProfiler
@@ -179,14 +176,15 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
         """
         cls = self.__class__
         if not isinstance(other_profile, cls):
-            raise TypeError("Unsupported operand type(s) for diff: '{}' "
-                            "and '{}'".format(cls.__name__,
-                                              other_profile.__class__.__name__))
+            raise TypeError(
+                "Unsupported operand type(s) for diff: '{}' "
+                "and '{}'".format(cls.__name__, other_profile.__class__.__name__)
+            )
         return {}
 
     def _update_column_base_properties(self, profile):
         """
-        Updates the base properties with the base schema.
+        Update the base properties with the base schema.
 
         :param profile: profile dictionary of data type
         :type profile: dict
@@ -198,6 +196,7 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
     def __getitem__(self, item):
         """
         Override for the [] operator to allow access to class properties.
+
         NOTE: Will be removed when switched over, only used as a method to
         integrate with current setup.
         """
@@ -207,15 +206,13 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
 
     @abc.abstractmethod
     def _update_helper(self, df_series_clean, profile):
-        """
-        Private abstract method for updating the profile.
-        """
+        """Help update the profile."""
         raise NotImplementedError()
 
     @abc.abstractmethod
     def update(self, df_series):
         """
-        Private abstract method for updating the profile.
+        Update the profile.
 
         :param df_series: Data to profile.
         :type df_series: Pandas Dataframe
@@ -225,33 +222,27 @@ class BaseColumnProfiler(with_metaclass(abc.ABCMeta, object)):
     @property
     @abc.abstractmethod
     def profile(self):
-        """
-        Property for profile. Returns the profile of the column.
-        """
+        """Return the profile of the column."""
         raise NotImplementedError()
 
     @abc.abstractmethod
     def report(self, remove_disabled_flag=False):
         """
-        Private abstract method for returning report.
+        Return report.
 
-        :param remove_disabled_flag: flag to determine if disabled 
+        :param remove_disabled_flag: flag to determine if disabled
             options should be excluded in the report.
         :type remove_disabled_flag: boolean
         """
-
         raise NotImplementedError()
 
 
-class BaseColumnPrimitiveTypeProfiler(with_metaclass(abc.ABCMeta,
-                                                     BaseColumnProfiler)):
-    """
-    Abstract class for profiling the primative data type for a column of data.
-    """
+class BaseColumnPrimitiveTypeProfiler(with_metaclass(abc.ABCMeta, BaseColumnProfiler)):
+    """Abstract class for profiling primative data type for col of data."""
 
     def __init__(self, name):
         """
-        Initialization of base class properties for the subclass.
+        Initialize base class properties for the subclass.
 
         :param name: Name of the data
         :type name: String
@@ -259,23 +250,22 @@ class BaseColumnPrimitiveTypeProfiler(with_metaclass(abc.ABCMeta,
         BaseColumnProfiler.__init__(self, name)
         # Number of values that match the column type. eg. how many floats match
         # in the float column
-        self.match_count = 0 
+        self.match_count = 0
 
     def _update_column_base_properties(self, profile):
         """
-        Updates the base properties with the base schema.
+        Update the base properties with the base schema.
 
         :param profile: profile containg base properties
         :type profile: base data profile dict
         :return: None
         """
         self.match_count += profile.pop("match_count")
-        BaseColumnProfiler. \
-            _update_column_base_properties(self, profile)
+        BaseColumnProfiler._update_column_base_properties(self, profile)
 
     def _add_helper(self, other1, other2):
         """
-        Merges the properties of two objects inputted
+        Merge the properties of two objects inputted.
 
         :param other1: first profile
         :param other2: second profile
