@@ -1,17 +1,21 @@
+"""Index profile analysis for individual col within structured profiling."""
+
 from . import BaseColumnProfiler, utils
 from .profiler_options import OrderOptions
 
 
 class OrderColumn(BaseColumnProfiler):
     """
-    Index column profile subclass of BaseColumnProfiler. Represents a column in
-    the dataset which is an index column.
+    Index column profile subclass of BaseColumnProfiler.
+
+    Represents a column in the dataset which is an index column.
     """
+
     type = "order"
 
     def __init__(self, name, options=None):
         """
-        Initialization of column base properties and itself.
+        Initialize column base properties and self.
 
         :param name: Name of the data
         :type name: String
@@ -19,8 +23,9 @@ class OrderColumn(BaseColumnProfiler):
         :type options: OrderOptions
         """
         if options and not isinstance(options, OrderOptions):
-            raise ValueError("OrderColumn parameter 'options' must be of type"
-                             " OrderOptions.")
+            raise ValueError(
+                "OrderColumn parameter 'options' must be of type" " OrderOptions."
+            )
         self.order = None
         self._last_value = None
         self._first_value = None
@@ -32,7 +37,7 @@ class OrderColumn(BaseColumnProfiler):
     @staticmethod
     def _is_intersecting(first_value1, last_value1, first_value2, last_value2):
         """
-        Checks to see if the range of the datasets intersect
+        Check to see if the range of the datasets intersect.
 
         :param first_value1: beginning value of dataset 1
         :type first_value1: Integer
@@ -53,18 +58,20 @@ class OrderColumn(BaseColumnProfiler):
         high_value2 = max(first_value2, last_value2)
         is_intersecting = False
 
-        if (low_value2 < low_value1 < high_value2) \
-                or (low_value2 < high_value1 < high_value2) \
-                or (low_value1 < low_value2 < high_value1) \
-                or (low_value1 < high_value2 < high_value1)\
-                or (low_value1 == low_value2 and high_value1 == high_value2):
+        if (
+            (low_value2 < low_value1 < high_value2)
+            or (low_value2 < high_value1 < high_value2)
+            or (low_value1 < low_value2 < high_value1)
+            or (low_value1 < high_value2 < high_value1)
+            or (low_value1 == low_value2 and high_value1 == high_value2)
+        ):
             is_intersecting = True
         return is_intersecting
 
     @staticmethod
     def _is_enveloping(first_value1, last_value1, first_value2, last_value2):
         """
-        Checks to see if the range of the dataset 1 envelopes dataset 2
+        Check to see if the range of the dataset 1 envelopes dataset 2.
 
         :param first_value1: beginning value of dataset 1
         :type first_value1: Integer
@@ -89,10 +96,19 @@ class OrderColumn(BaseColumnProfiler):
         return is_enveloping
 
     @BaseColumnProfiler._timeit(name="order")
-    def _merge_order(self, order1, first_value1, last_value1, piecewise1,
-                     order2, first_value2, last_value2, piecewise2):
+    def _merge_order(
+        self,
+        order1,
+        first_value1,
+        last_value1,
+        piecewise1,
+        order2,
+        first_value2,
+        last_value2,
+        piecewise2,
+    ):
         """
-        Adds the order of two datasets together
+        Add the order of two datasets together.
 
         :param order1: order of original dataset
         :param first_value1: beginning value of original dataset
@@ -119,12 +135,15 @@ class OrderColumn(BaseColumnProfiler):
         elif not order2:
             return order1, first_value1, last_value1, piecewise1
 
-        is_intersecting = self._is_intersecting(first_value1, last_value1,
-                                                first_value2, last_value2)
-        self_envelopes_other = self._is_enveloping(first_value1, last_value1,
-                                                   first_value2, last_value2)
-        other_envelopes_self = self._is_enveloping(first_value2, last_value2,
-                                                   first_value1, last_value1)
+        is_intersecting = self._is_intersecting(
+            first_value1, last_value1, first_value2, last_value2
+        )
+        self_envelopes_other = self._is_enveloping(
+            first_value1, last_value1, first_value2, last_value2
+        )
+        other_envelopes_self = self._is_enveloping(
+            first_value2, last_value2, first_value1, last_value1
+        )
 
         # Default initialization
         order = "random"
@@ -138,19 +157,22 @@ class OrderColumn(BaseColumnProfiler):
         elif order1 == order2:
             if not is_intersecting or (piecewise1 and piecewise2):
                 order = order1
-            elif piecewise1 and self_envelopes_other:  # Intersect and not both piecewise
+            elif (
+                piecewise1 and self_envelopes_other
+            ):  # Intersect and not both piecewise
                 order = order1
             elif piecewise2 and other_envelopes_self:
                 order = order1
             elif order1 == "constant value":  # Constants that intersect
                 order = order1
             else:  # Ascending/Descending that intersect but not both piecewise
-                   # and dont envelope one or the other
+                # and dont envelope one or the other
                 order = "random"
 
         # Neither Random, nor the same order
-        elif (order1 == "ascending" and order2 == "descending") or \
-                (order1 == "descending" and order2 == "ascending"):
+        elif (order1 == "ascending" and order2 == "descending") or (
+            order1 == "descending" and order2 == "ascending"
+        ):
             order = "random"
 
         # One must be ascending/descending and one must be constant
@@ -178,27 +200,20 @@ class OrderColumn(BaseColumnProfiler):
             first_value = max(first_value1, first_value2)
             last_value = min(last_value1, last_value2)
         elif order == "random" or order == "constant value":
-            first_value = min(
-                first_value1,
-                first_value2,
-                last_value1,
-                last_value2)
-            last_value = max(
-                first_value1,
-                first_value2,
-                last_value1,
-                last_value2)
+            first_value = min(first_value1, first_value2, last_value1, last_value2)
+            last_value = max(first_value1, first_value2, last_value1, last_value2)
 
         piecewise = True
-        if (order == "constant value" and first_value == last_value) \
-                or order == "random":
+        if (
+            order == "constant value" and first_value == last_value
+        ) or order == "random":
             piecewise = False
 
         return order, first_value, last_value, piecewise
 
     def __add__(self, other):
         """
-        Merges the properties of two OrderColumn profiles
+        Merge the properties of two OrderColumn profiles.
 
         :param self: first profile
         :param other: second profile
@@ -208,14 +223,22 @@ class OrderColumn(BaseColumnProfiler):
         :rtype: OrderColumn
         """
         if not isinstance(other, OrderColumn):
-            raise TypeError("Unsupported operand type(s) for +: "
-                            "'OrderColumn' and '{}'".format(
-                                other.__class__.__name__))
+            raise TypeError(
+                "Unsupported operand type(s) for +: "
+                "'OrderColumn' and '{}'".format(other.__class__.__name__)
+            )
 
         merged_profile = OrderColumn(None)
         order, first_value, last_value, piecewise = self._merge_order(
-            self.order, self._first_value, self._last_value, self._piecewise, 
-            other.order, other._first_value, other._last_value, other._piecewise)
+            self.order,
+            self._first_value,
+            self._last_value,
+            self._piecewise,
+            other.order,
+            other._first_value,
+            other._last_value,
+            other._piecewise,
+        )
 
         merged_profile.order = order
         merged_profile._first_value = first_value
@@ -223,9 +246,9 @@ class OrderColumn(BaseColumnProfiler):
         merged_profile._piecewise = piecewise
 
         BaseColumnProfiler._add_helper(merged_profile, self, other)
-        self._merge_calculations(merged_profile.__calculations,
-                                 self.__calculations,
-                                 other.__calculations)
+        self._merge_calculations(
+            merged_profile.__calculations, self.__calculations, other.__calculations
+        )
         return merged_profile
 
     def report(self, remove_disabled_flag=False):
@@ -249,7 +272,7 @@ class OrderColumn(BaseColumnProfiler):
 
     def diff(self, other_profile, options=None):
         """
-        Generates the differences between the orders of two OrderColumns
+        Generate the differences between the orders of two OrderColumns.
 
         :return: Dict containing the differences between orders in their
         appropriate output formats
@@ -258,17 +281,19 @@ class OrderColumn(BaseColumnProfiler):
         super().diff(other_profile, options)
 
         differences = {
-            "order": utils.find_diff_of_strings_and_bools(self.order, 
-                                                          other_profile.order)
+            "order": utils.find_diff_of_strings_and_bools(
+                self.order, other_profile.order
+            )
         }
         return differences
 
     @BaseColumnProfiler._timeit(name="order")
     def _get_data_order(self, df_series):
         """
-        Retrieves the order profile of a given data series.
-        Will return either: ascending, descending, constant value, or random.
-        Additionally, returns the first and last value of the series.
+        Retrieve the order profile of a given data series.
+
+        Return either: ascending, descending, constant value, or random.
+        Additionally, return the first and last value of the series.
 
         :param df_series: a given column
         :type df_series: pandas.core.series.Series
@@ -286,27 +311,29 @@ class OrderColumn(BaseColumnProfiler):
 
         for i in range(1, len(df_series)):
             value = df_series.iloc[i]
-            if value < last_value and order == 'ascending':
-                order = 'random'
+            if value < last_value and order == "ascending":
+                order = "random"
                 break
             elif value < last_value and order is None:
-                order = 'descending'
-            elif value > last_value and order == 'descending':
-                order = 'random'
+                order = "descending"
+            elif value > last_value and order == "descending":
+                order = "random"
                 break
             elif value > last_value and order is None:
-                order = 'ascending'
+                order = "ascending"
             last_value = value
         if not order:
             order = "constant value"
 
         return order, first_value, last_value
 
-    def _update_order(self, df_series, prev_dependent_properties=None, 
-                      subset_properties=None):
+    def _update_order(
+        self, df_series, prev_dependent_properties=None, subset_properties=None
+    ):
         """
-        Updates the order profile with order information attained
-        from the new dataset in two steps:
+        Update order profile with order info attained from new dataset.
+
+        Do this in following two steps:
         1. Get order information from input column data.
         2. Merge information between existing profile and new column
            order information.
@@ -325,16 +352,25 @@ class OrderColumn(BaseColumnProfiler):
             return
         order, first_value, last_value = self._get_data_order(df_series)
 
-        self.order, self._first_value, self._last_value, self._piecewise = \
-            self._merge_order(self.order, self._first_value,
-                              self._last_value, self._piecewise, order,
-                              first_value, last_value,
-                              piecewise2=False)
+        (
+            self.order,
+            self._first_value,
+            self._last_value,
+            self._piecewise,
+        ) = self._merge_order(
+            self.order,
+            self._first_value,
+            self._last_value,
+            self._piecewise,
+            order,
+            first_value,
+            last_value,
+            piecewise2=False,
+        )
 
     def _update_helper(self, df_series_clean, profile):
         """
-        Method for updating the column profile properties with a cleaned
-        dataset and the known null parameters of the dataset.
+        Update col profile properties with clean dataset and its known null parameters.
 
         :param df_series_clean: df series with nulls removed
         :type df_series_clean: pandas.core.series.Series
@@ -346,7 +382,7 @@ class OrderColumn(BaseColumnProfiler):
 
     def update(self, df_series):
         """
-        Updates the column profile.
+        Update the column profile.
 
         :param df_series: df series
         :type df_series: pandas.core.series.Series
@@ -358,8 +394,12 @@ class OrderColumn(BaseColumnProfiler):
         profile = dict(sample_size=len(df_series))
         OrderColumn._update_order(self, df_series=df_series)
         BaseColumnProfiler._perform_property_calcs(
-            self, self.__calculations, df_series=df_series,
-            prev_dependent_properties={}, subset_properties=profile)
+            self,
+            self.__calculations,
+            df_series=df_series,
+            prev_dependent_properties={},
+            subset_properties=profile,
+        )
         self._update_helper(df_series, profile)
 
         return self
