@@ -1,10 +1,11 @@
 from dataprofiler.profilers.profiler_options import TextOptions
-from dataprofiler.tests.profilers.profiler_options.test_numerical_options import \
-    TestNumericalOptions
+from dataprofiler.tests.profilers.profiler_options.test_numerical_options import (
+    TestNumericalOptions,
+)
 
 
 class TestTextOptions(TestNumericalOptions):
-    
+
     option_class = TextOptions
     keys = TestNumericalOptions.keys + ["vocab"]
     numeric_keys = TestNumericalOptions.numeric_keys.copy()
@@ -13,13 +14,13 @@ class TestTextOptions(TestNumericalOptions):
 
     def test_init(self):
         super().test_init()
-    
+
     def test_set_helper(self):
         super().test_set_helper()
 
     def test_set(self):
         super().test_set()
-    
+
     def test_validate_helper(self):
         super().test_validate_helper()
         options = self.get_options()
@@ -27,9 +28,11 @@ class TestTextOptions(TestNumericalOptions):
 
         # Check to make sure num_zeros/num_negatives is False as a TextOption
         for key in ["num_zeros", "num_negatives"]:
-            skey = '{}.is_enabled'.format(key)
-            expected_error = "{}.{} should always be disabled, "\
-                             "{}.is_enabled = False".format(optpth, key, key)
+            skey = "{}.is_enabled".format(key)
+            expected_error = (
+                "{}.{} should always be disabled, "
+                "{}.is_enabled = False".format(optpth, key, key)
+            )
             default_bool = options.properties[key].is_enabled
             options.set({skey: True})
             self.assertEqual([expected_error], options._validate_helper())
@@ -37,7 +40,7 @@ class TestTextOptions(TestNumericalOptions):
 
     def test_validate(self):
         super().test_validate()
-    
+
     def test_is_numeric_stats_enabled(self):
         super().test_is_numeric_stats_enabled()
 
@@ -45,11 +48,10 @@ class TestTextOptions(TestNumericalOptions):
 
         # Disable All Numeric Stats but cheeck num_zeros and num_negatives
         # will not affect is_numeric_stats_enabled
-        options.set({'{}.is_enabled'.format(key): False
-                     for key in self.numeric_keys})
-        options.set({'num_zeros.is_enabled': True})
+        options.set({"{}.is_enabled".format(key): False for key in self.numeric_keys})
+        options.set({"num_zeros.is_enabled": True})
         self.assertFalse(options.is_numeric_stats_enabled)
-        options.set({'num_negatives.is_enabled': True})
+        options.set({"num_negatives.is_enabled": True})
         self.assertFalse(options.is_numeric_stats_enabled)
 
         # Make sure these two variables cannot be influenced by
