@@ -61,7 +61,7 @@ class TestShuffleInChunks(unittest.TestCase):
 
         # Ensure lists and sets are handled appropriately
         self.assertEqual(
-            "unchanged", utils.find_diff_of_lists_and_sets([3, 2], [2, 3, 2])
+            [[], [3, 2], [2]], utils.find_diff_of_lists_and_sets([3, 2], [2, 3, 2])
         )
         self.assertEqual(
             [[1], [2, 3], [4]], utils.find_diff_of_lists_and_sets([1, 2, 3], [2, 3, 4])
@@ -134,6 +134,42 @@ class TestShuffleInChunks(unittest.TestCase):
         }
         self.assertDictEqual(expected_diff, utils.find_diff_of_dicts(dict1, dict2))
 
+        dict1 = {
+            "nested_key_one": {"fruit": ["apple", "banana", "orange"], "yes_no": False},
+            "key_one": True,
+            "attributes": {"value": 5, "id": 10},
+            "last_nested_key": {"color": "blue", "weight": 35},
+        }
+
+        dict2 = {
+            "nested_key_two": {"fruit": ["apple", "banana", "orange"], "yes_no": True},
+            "key_one": True,
+            "attributes": {"value": None, "id": 10},
+            "last_nested_key": {"weight": 35, "height": "500"},
+            "additional_key": "random_string",
+        }
+
+        expected_diff = {
+            "nested_key_one": [
+                {"fruit": ["apple", "banana", "orange"], "yes_no": False},
+                None,
+            ],
+            "key_one": "unchanged",
+            "attributes": {"value": [5, None], "id": "unchanged"},
+            "last_nested_key": {
+                "color": ["blue", None],
+                "weight": "unchanged",
+                "height": [None, "500"],
+            },
+            "nested_key_two": [
+                None,
+                {"fruit": ["apple", "banana", "orange"], "yes_no": True},
+            ],
+            "additional_key": [None, "random_string"],
+        }
+
+        self.assertDictEqual(expected_diff, utils.find_diff_of_dicts(dict1, dict2))
+
     def test_diff_of_dicts_with_diff_keys(self):
         dict1 = {"unique1": 1, "shared1": 2, "shared2": 3}
         dict2 = {"unique2": 5, "shared1": 2, "shared2": 6}
@@ -183,6 +219,87 @@ class TestShuffleInChunks(unittest.TestCase):
             expected, utils.find_diff_of_dicts_with_diff_keys(dict1, dict2)
         )
 
+        dict1 = {
+            "nested_key_one": {"fruit": ["apple", "banana", "orange"], "yes_no": False},
+            "key_one": True,
+            "attributes": {"value": 5, "id": 10},
+            "last_nested_key": {"color": "blue", "weight": 35},
+        }
+
+        dict2 = {
+            "nested_key_two": {"fruit": ["apple", "banana", "orange"], "yes_no": True},
+            "key_one": True,
+            "attributes": {"value": None, "id": 10},
+            "last_nested_key": {"weight": 35, "height": "500"},
+            "additional_key": "random_string",
+        }
+
+        expected = [
+            {
+                "nested_key_one": {
+                    "fruit": ["apple", "banana", "orange"],
+                    "yes_no": False,
+                }
+            },
+            {
+                "key_one": "unchanged",
+                "attributes": [{}, {"value": [5, None], "id": "unchanged"}, {}],
+                "last_nested_key": [
+                    {"color": "blue"},
+                    {"weight": "unchanged"},
+                    {"height": "500"},
+                ],
+            },
+            {
+                "nested_key_two": {
+                    "fruit": ["apple", "banana", "orange"],
+                    "yes_no": True,
+                },
+                "additional_key": "random_string",
+            },
+        ]
+
+        self.assertListEqual(
+            expected, utils.find_diff_of_dicts_with_diff_keys(dict1, dict2)
+        )
+
+    def test_list_diff_with_nan(self):
+        # when lists are same length
+        list_1 = [np.nan, 1.5, 6.7]
+        list_2 = [np.nan, 1.5, np.nan]
+        diff_1 = utils.find_diff_of_lists_and_sets(list_1, list_2)
+        expected_diff_1 = [[6.7], [np.nan, 1.5], [np.nan]]
+
+        for x, y in zip(diff_1, expected_diff_1):
+            comparison_1 = ((x == y) | (np.isnan(x) & np.isnan(y))).all()
+            self.assertEqual(True, comparison_1)
+
+        # when lists aren't the same length
+        list_3 = [np.nan, 1.5, 6.7, np.nan, np.nan, np.nan]
+        list_4 = [4.2, 1.5, np.nan]
+        diff_2 = utils.find_diff_of_lists_and_sets(list_3, list_4)
+        expected_diff_2 = [[6.7, np.nan, np.nan, np.nan], [np.nan, 1.5], [4.2]]
+
+        for x, y in zip(diff_2, expected_diff_2):
+            comparison_2 = ((x == y) | (np.isnan(x) & np.isnan(y))).all()
+            self.assertEqual(True, comparison_2)
+
+        list_5 = [np.nan, np.nan]
+        list_6 = [np.nan]
+        diff_3 = utils.find_diff_of_lists_and_sets(list_5, list_6)
+        expected_diff_3 = [[np.nan], [np.nan], []]
+
+        for x, y in zip(diff_3, expected_diff_3):
+            comparison_3 = ((x == y) | (np.isnan(x) & np.isnan(y))).all()
+            self.assertEqual(True, comparison_3)
+
+        list_7 = [np.nan, 3]
+        list_8 = [np.nan, 3]
+        diff_4 = utils.find_diff_of_lists_and_sets(list_7, list_8)
+        expected_diff_4 = "unchanged"
+
+        self.assertEqual(diff_4, expected_diff_4)
+
     def test_find_diff_of_matrices(self):
         import numpy as np
 
