@@ -13,18 +13,18 @@ MODULE_PATH = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 
 
 class TestDataValidator(unittest.TestCase):
-
     @classmethod
     def setUpClass(cls):
 
-        test_dir = os.path.join(MODULE_PATH, 'data')
+        test_dir = os.path.join(MODULE_PATH, "data")
         cls.input_file_names = [
-            dict(path=os.path.join(
-                test_dir, 'csv/aws_honeypot_marx_geo.csv'), type='csv'),
+            dict(
+                path=os.path.join(test_dir, "csv/aws_honeypot_marx_geo.csv"), type="csv"
+            ),
         ]
 
         file = cls.input_file_names[0]
-        data = Data(file['path'])
+        data = Data(file["path"])
         sub_data = data.data.head(100)
         cls.sub_data = sub_data
         cls.dask_data = dd.from_pandas(sub_data, npartitions=2)
@@ -32,73 +32,50 @@ class TestDataValidator(unittest.TestCase):
         cls.correct_pandas_config = {
             "df_type": "pandas",
             "known_anomaly_validation": {
-                "int_col": {
-                    "range": {
-                        "start": 3000,
-                        "end": 4000
-                    },
-                    "list": [2192]
-                }
-            }
+                "int_col": {"range": {"start": 3000, "end": 4000}, "list": [2192]}
+            },
         }
 
         cls.correct_dask_config = {
             "df_type": "dask",
             "known_anomaly_validation": {
-                "int_col": {
-                    "range": {
-                        "start": 3000,
-                        "end": 4000},
-                    "list": [2192]
-                }
-            }
+                "int_col": {"range": {"start": 3000, "end": 4000}, "list": [2192]}
+            },
         }
 
         cls.wrong_config = {
             "df_type": "pandas",
             "known_anomaly_validation": {
-                "int_col": {
-                    "rng": {
-                        "start": 3000,
-                        "end": 4000}
-                }
-            }
+                "int_col": {"rng": {"start": 3000, "end": 4000}}
+            },
         }
 
         cls.empty_config = {
             "df_type": "pandas",
-            "known_anomaly_validation": {
-                "int_col": {
-                }
-            }
+            "known_anomaly_validation": {"int_col": {}},
         }
 
         cls.true_results = {
             "df_type": "pandas",
             "known_anomaly_validation": {
-                'int_col': {
-                    'range': [1,  2,  5, 13, 24, 45, 52, 75, 98],
-                    'list': [99]
-                }
-            }
+                "int_col": {"range": [1, 2, 5, 13, 24, 45, 52, 75, 98], "list": [99]}
+            },
         }
 
     def test_data_validation(self):
         """
-        Testing to ensure that the validate method does not return None. 
+        Testing to ensure that the validate method does not return None.
         """
         validator = Validator()
-        validator.validate(data=self.sub_data,
-                           config=self.correct_pandas_config)
+        validator.validate(data=self.sub_data, config=self.correct_pandas_config)
         self.assertIsNotNone(validator.validation_report)
 
     def test_dask_data_validation(self):
         """
-        Testing to ensure that the validate method does not return None. 
+        Testing to ensure that the validate method does not return None.
         """
         validator = Validator()
-        validator.validate(data=self.dask_data,
-                           config=self.correct_dask_config)
+        validator.validate(data=self.dask_data, config=self.correct_dask_config)
         self.assertIsNotNone(validator.validation_report)
 
     def test_data_validation_output(self):
@@ -106,17 +83,20 @@ class TestDataValidator(unittest.TestCase):
         Test that the validation runs and returns the correct output.
         """
         validator = Validator()
-        validator.validate(data=self.sub_data,
-                           config=self.correct_pandas_config)
-        self.assertEqual(validator.validation_report['int_col']['range'],
-                         self.true_results['known_anomaly_validation']['int_col']['range'])
-        self.assertEqual(validator.validation_report['int_col']['list'],
-                         self.true_results['known_anomaly_validation']['int_col']['list'])
+        validator.validate(data=self.sub_data, config=self.correct_pandas_config)
+        self.assertEqual(
+            validator.validation_report["int_col"]["range"],
+            self.true_results["known_anomaly_validation"]["int_col"]["range"],
+        )
+        self.assertEqual(
+            validator.validation_report["int_col"]["list"],
+            self.true_results["known_anomaly_validation"]["int_col"]["list"],
+        )
 
     def test_data_validation_wrong_config(self):
         """
-        Test that the validation method raises exceptions when provided 
-        a wrong configuration dictionary. 
+        Test that the validation method raises exceptions when provided
+        a wrong configuration dictionary.
         """
         validator = Validator()
         with self.assertRaises(TypeError):
@@ -124,8 +104,8 @@ class TestDataValidator(unittest.TestCase):
 
     def test_data_validation_empty_config(self):
         """
-        Test that the validation method raises exceptions when provided 
-        a empty configuration dictionary. 
+        Test that the validation method raises exceptions when provided
+        a empty configuration dictionary.
         """
         validator = Validator()
         with self.assertRaises(Warning):
@@ -133,13 +113,13 @@ class TestDataValidator(unittest.TestCase):
 
     def test_data_validation_no_run_with_get(self):
         """
-        Test that the validation method raises exceptions when provided 
-        a empty configuration dictionary. 
+        Test that the validation method raises exceptions when provided
+        a empty configuration dictionary.
         """
         validator = Validator()
         with self.assertRaises(Warning):
             validator.get()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
